# COSMOS telemetry

This is a simple package to help you connect your drone to COSMOS API by:
- Generating End-Point.
- Generating and processing Post-Request to the End-point.

For more information check [COSMOS-API](https://dmtest.cosmos.ali.jp/docapi).